%{!?kernel_version: %{expand: %%define kernel_version %(uname -r|sed -e 's/EL.*$/EL/g')}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %define type %(uname -r | sed -e 's/.*EL//g' | sed -e 's/^$/up/g')}}

# On RHEL 4, up type has no tag
%if "%{type}" != "up"
%define releasetag %{kversionreltag}.%{type}
%define kernel_dir %{kernel_version}%{type}
%define kernel_devel kernel-%{type}-devel
%else
%define releasetag %{kversionreltag}
%define kernel_dir %{kernel_version}
%define kernel_devel kernel-devel
%endif

# Keep the modKey def identical to that in util.sh-PMWV.*
%define modKey 'PMWV|%{type}|vmxnet3'
%define vmwDB /usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-db.pl --os=linux,rhel,4
%define vmwPMWV /usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-pmwv.pl --os=linux,rhel,4 --release=%{kernel_dir} --build 519389 --modKey %{modKey}
%define kmp_version %version

Name:         vmware-tools-vmxnet3
BuildRequires: %{kernel_devel} gcc
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      Contains the source needed to build the vmxnet3 kernel module package (kmp) for the running kernel.
Epoch:        0
Version:      1.0.37.0
Release:      3
BuildRoot:    %{_tmppath}/%{name}-%{version}-build
Source1:      vmxnet3-configModule.tar.gz

Source0:      vmxnet3.tar

%prep
%setup -n vmxnet3-only

%build
make clean
make

# NOTE: RHEL 4 has MODVERSIONS enabled but does not generate the module.symvers
#       file we would need in order to properly propagate symbol versions
#       in-between interdependent kernel modules.  See bug 568405 for more info.
if [ "vmxnet3" = "vsock" -o "vmxnet3" = "vmhgfs" ]; then
   echo
   echo
   echo "Please ignore the \"VMCI_ ... undefined!\" warnings generated by the build system."
   echo "The vmxnet3 module will load and function properly despite those warnings."
   echo
   echo
fi

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
# The following command copies our newly build kernel module to a known
# location.  Unfortunately sometimes the kmod source build places the kmods
# in inconsistent locations.
cp ../vmxnet3.o . 2>/dev/null || true
cp driver-%{kernel_version}/vmxnet3-xxx-%{kernel_version} ./vmxnet3.o 2>/dev/null || true

# Install kernel module
install -m 644 -D vmxnet3.o $RPM_BUILD_ROOT/lib/modules/%{kernel_dir}/extra/%{name}/vmxnet3.ko
# Install common files
cd $RPM_BUILD_ROOT && tar xzf %{SOURCE1}

%description
 This package enables you to build binary kernel module packages (kmps) for vmxnet3.  The vmxnet3 kernel module allows for enhanced network performance on the vmxnet3 virtual network device.

%package common
Summary:      Contains the common files used by all the vmxnet3 kernel module packages (kmps).
Group:        System/Kernel
Requires:     perl
Requires:     vmware-tools-foundation >= 0:8.6.0
Release:      3
Version:      8.6.0

%description common
 This package contains the common system configuration and scripts responsible for loading the vmxnet3 kernel module.  The vmxnet3 kernel module allows for enhanced network performance on the vmxnet3 virtual network device.

%package kmp-%{type}
Summary:      The vmxnet3 kernel module built for the %{kernel_version} kernel.
Group:        System/Kernel
Requires:     vmware-tools-vmxnet3-common
Requires:     vmware-tools-foundation >= 0:8.6.0
Provides:     vmware-tools-vmxnet3-kmp
Release:      %{kversionreltag}.3


%description kmp-%{type}
 This package contains a pre-compiled vmxnet3 module for use with the %{kernel_version} kernel.   The vmxnet3 kernel module allows for enhanced network performance on the vmxnet3 virtual network device.

%pre kmp-%{type}
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   # If the type matches, stop the init script
   kmodType=`uname -r | sed -e 's/.*EL//g'`
   if [ -z "$kmodType" ]; then
      kmodType=up
   fi
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vmxnet3 stop
   fi

   %{vmwPMWV} --rpmSection=Postun
fi

# Configure
%{vmwPMWV} --rpmSection=Pre

%pre common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vmxnet3 ]; then
      /sbin/chkconfig vmxnet3 off
   fi
   /usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-deconfig.pl --os=linux,rhel,4 --toDeconfigure=vmxnet3
   /usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-db.pl --os=linux,rhel,4 --dbDelAnswer VMXNET3_NAME
fi

%post common
/usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-db.pl --os=linux,rhel,4 --dbAddAnswer VMXNET3_NAME,vmxnet3
/usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-config.pl --os=linux,rhel,4 --toConfigure=vmxnet3
if [ -e /etc/init.d/vmxnet3 ]; then
   /sbin/chkconfig vmxnet3 on
fi

%post kmp-%{type}
# Configure
# Invoke the PMWV Post Section
%{vmwPMWV} --rpmSection=Post --baseMod=/lib/modules/%{kernel_dir}/extra/%{name}/vmxnet3.ko

# If the type matches, start the init script
kmodType=`uname -r | sed -e 's/.*EL//g'`
if [ -z "$kmodType" ]; then
   kmodType=up
fi
if [ "$kmodType" = "%{type}" ]; then
   /etc/init.d/vmxnet3 start
fi

%preun common
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   if [ -e /etc/init.d/vmxnet3 ]; then
      /sbin/chkconfig vmxnet3 off
   fi
   /usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-deconfig.pl --os=linux,rhel,4 --toDeconfigure=vmxnet3
   /usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-db.pl --os=linux,rhel,4 --dbDelAnswer VMXNET3_NAME
fi

%preun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   # If the type matches, stop the init script
   kmodType=`uname -r | sed -e 's/.*EL//g'`
   if [ -z "$kmodType" ]; then
      kmodType=up
   fi
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vmxnet3 stop
   fi
fi

%postun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   %{vmwPMWV} --rpmSection=Postun
fi

%files common
%defattr(-, root, root, -)
/usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-pmwv.pl
/usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-deconfig.pl
/usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-db.pl
/usr/lib/vmware-tools/moduleScripts/vmxnet3/vmware-config.pl
/etc/rc.d/init.d/vmxnet3
%dir /usr/lib/vmware-tools/moduleScripts/vmxnet3
%dir /usr/lib/vmware-tools/moduleScripts
%dir /usr/lib/vmware-tools
%dir /usr/lib
%dir /usr
%dir /etc/rc.d/init.d
%dir /etc/rc.d
%dir /etc

%files kmp-%{type}
%defattr(-, root, root, -)
/lib/modules/%{kernel_dir}/extra/%{name}/vmxnet3.ko


